==> libcamera-docs-0.6.0-2-x86_64.pkg.tar.zst: usr/share/doc/libcamera/html/internal-api/namespacelibcamera_1_1ipa.js <==
var namespacelibcamera_1_1ipa =
[
    [ "AgcMeanLuminance", "classlibcamera_1_1ipa_1_1AgcMeanLuminance.html", "classlibcamera_1_1ipa_1_1AgcMeanLuminance" ],
    [ "Algorithm", "classlibcamera_1_1ipa_1_1Algorithm.html", "classlibcamera_1_1ipa_1_1Algorithm" ],
    [ "AlgorithmFactory", "classlibcamera_1_1ipa_1_1AlgorithmFactory.html", "classlibcamera_1_1ipa_1_1AlgorithmFactory" ],
    [ "AwbResult", "structlibcamera_1_1ipa_1_1AwbResult.html", "structlibcamera_1_1ipa_1_1AwbResult" ],
    [ "AwbStats", "structlibcamera_1_1ipa_1_1AwbStats.html", "structlibcamera_1_1ipa_1_1AwbStats" ],
    [ "AwbAlgorithm", "classlibcamera_1_1ipa_1_1AwbAlgorithm.html", "classlibcamera_1_1ipa_1_1AwbAlgorithm" ],
    [ "AwbBayes", "classlibcamera_1_1ipa_1_1AwbBayes.html", "classlibcamera_1_1ipa_1_1AwbBayes" ],
    [ "AwbGrey", "classlibcamera_1_1ipa_1_1AwbGrey.html", "classlibcamera_1_1ipa_1_1AwbGrey" ],
    [ "CameraSensorHelper", "classlibcamera_1_1ipa_1_1CameraSensorHelper.html", "classlibcamera_1_1ipa_1_1CameraSensorHelper" ],
    [ "CameraSensorHelperFactoryBase", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase.html", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase" ],
    [ "CameraSensorHelperFactory", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory.html", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory" ],
    [ "ExposureModeHelper", "classlibcamera_1_1ipa_1_1ExposureModeHelper.html", "classlibcamera_1_1ipa_1_1ExposureModeHelper" ],
    [ "FCQueue", "classlibcamera_1_1ipa_1_1FCQueue.html", "classlibcamera_1_1ipa_1_1FCQueue" ],
    [ "FrameContext", "structlibcamera_1_1ipa_1_1FrameContext.html", null ],
    [ "Histogram", "classlibcamera_1_1ipa_1_1Histogram.html", "classlibcamera_1_1ipa_1_1Histogram" ],
    [ "Interpolator", "classlibcamera_1_1ipa_1_1Interpolator.html", "classlibcamera_1_1ipa_1_1Interpolator" ],
    [ "LscPolynomial", "classlibcamera_1_1ipa_1_1LscPolynomial.html", "classlibcamera_1_1ipa_1_1LscPolynomial" ],
    [ "Lux", "classlibcamera_1_1ipa_1_1Lux.html", "classlibcamera_1_1ipa_1_1Lux" ],
    [ "Module", "classlibcamera_1_1ipa_1_1Module.html", "classlibcamera_1_1ipa_1_1Module" ],
    [ "Pwl", "classlibcamera_1_1ipa_1_1Pwl.html", "classlibcamera_1_1ipa_1_1Pwl" ],
    [ "estimateCCT", "namespacelibcamera_1_1ipa.html#ab36f0747e1cf57eb11952f440271ac13", null ],
    [ "fixedToFloatingPoint", "namespacelibcamera_1_1ipa.html#a4fc5e9e613190d01666f10be118d3d7f", null ],
    [ "floatingToFixedPoint", "namespacelibcamera_1_1ipa.html#aa55669d4932614f81b90637ad553c745", null ],
    [ "rec601LuminanceFromRGB", "namespacelibcamera_1_1ipa.html#a64f2d4bbe57b6948d6dc48fbf81b3156", null ],
    [ "kSearchStep", "namespacelibcamera_1_1ipa.html#ad75064ee1a116143c11e18655dcbf95e", null ]
];

==> libcamera-docs-0.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/libcamera/html/internal-api/namespacelibcamera_1_1ipa.js <==
var namespacelibcamera_1_1ipa =
[
    [ "AgcMeanLuminance", "classlibcamera_1_1ipa_1_1AgcMeanLuminance.html", "classlibcamera_1_1ipa_1_1AgcMeanLuminance" ],
    [ "Algorithm", "classlibcamera_1_1ipa_1_1Algorithm.html", "classlibcamera_1_1ipa_1_1Algorithm" ],
    [ "AlgorithmFactory", "classlibcamera_1_1ipa_1_1AlgorithmFactory.html", "classlibcamera_1_1ipa_1_1AlgorithmFactory" ],
    [ "AwbResult", "structlibcamera_1_1ipa_1_1AwbResult.html", "structlibcamera_1_1ipa_1_1AwbResult" ],
    [ "AwbStats", "structlibcamera_1_1ipa_1_1AwbStats.html", "structlibcamera_1_1ipa_1_1AwbStats" ],
    [ "AwbAlgorithm", "classlibcamera_1_1ipa_1_1AwbAlgorithm.html", "classlibcamera_1_1ipa_1_1AwbAlgorithm" ],
    [ "AwbBayes", "classlibcamera_1_1ipa_1_1AwbBayes.html", "classlibcamera_1_1ipa_1_1AwbBayes" ],
    [ "AwbGrey", "classlibcamera_1_1ipa_1_1AwbGrey.html", "classlibcamera_1_1ipa_1_1AwbGrey" ],
    [ "CameraSensorHelper", "classlibcamera_1_1ipa_1_1CameraSensorHelper.html", "classlibcamera_1_1ipa_1_1CameraSensorHelper" ],
    [ "CameraSensorHelperFactoryBase", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase.html", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase" ],
    [ "CameraSensorHelperFactory", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory.html", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory" ],
    [ "ExposureModeHelper", "classlibcamera_1_1ipa_1_1ExposureModeHelper.html", "classlibcamera_1_1ipa_1_1ExposureModeHelper" ],
    [ "FCQueue", "classlibcamera_1_1ipa_1_1FCQueue.html", "classlibcamera_1_1ipa_1_1FCQueue" ],
    [ "FrameContext", "structlibcamera_1_1ipa_1_1FrameContext.html", null ],
    [ "Histogram", "classlibcamera_1_1ipa_1_1Histogram.html", "classlibcamera_1_1ipa_1_1Histogram" ],
    [ "Interpolator", "classlibcamera_1_1ipa_1_1Interpolator.html", "classlibcamera_1_1ipa_1_1Interpolator" ],
    [ "LscPolynomial", "classlibcamera_1_1ipa_1_1LscPolynomial.html", "classlibcamera_1_1ipa_1_1LscPolynomial" ],
    [ "Lux", "classlibcamera_1_1ipa_1_1Lux.html", "classlibcamera_1_1ipa_1_1Lux" ],
    [ "Module", "classlibcamera_1_1ipa_1_1Module.html", "classlibcamera_1_1ipa_1_1Module" ],
    [ "Pwl", "classlibcamera_1_1ipa_1_1Pwl.html", "classlibcamera_1_1ipa_1_1Pwl" ],
    [ "V4L2ParamsBlock", "classlibcamera_1_1ipa_1_1V4L2ParamsBlock.html", "classlibcamera_1_1ipa_1_1V4L2ParamsBlock" ],
    [ "V4L2Params", "classlibcamera_1_1ipa_1_1V4L2Params.html", "classlibcamera_1_1ipa_1_1V4L2Params" ],
    [ "estimateCCT", "namespacelibcamera_1_1ipa.html#ab36f0747e1cf57eb11952f440271ac13", null ],
    [ "fixedToFloatingPoint", "namespacelibcamera_1_1ipa.html#a4fc5e9e613190d01666f10be118d3d7f", null ],
    [ "floatingToFixedPoint", "namespacelibcamera_1_1ipa.html#aa55669d4932614f81b90637ad553c745", null ],
    [ "rec601LuminanceFromRGB", "namespacelibcamera_1_1ipa.html#a64f2d4bbe57b6948d6dc48fbf81b3156", null ],
    [ "kSearchStep", "namespacelibcamera_1_1ipa.html#ad75064ee1a116143c11e18655dcbf95e", null ]
];
